@@ -95,7 +95,7 @@ int fputc(int c, FILE* fp)
 */
 static void internal_exit()           __attribute__ ((noreturn));
 extern void mexErrMsgTxt(const char*) __attribute__ ((noreturn));
-       void exit()                    __attribute__ ((noreturn));
+       void exit(int)                    __attribute__ ((noreturn));
        void abort()                   __attribute__ ((noreturn));
 #endif
 
@@ -108,6 +108,7 @@ static void internal_exit()
 
 void exit(int status)
 {
+  (void)status;
   internal_exit();
 }
 void abort(void)
