@@ -137,22 +137,26 @@ void SDPA::setParameterEpsilonDash (double epsilonDash)
 
 void SDPA::setParameterPrintXVec(char* xPrint)
 {
-  strncpy(param.xPrint,xPrint,PRINT_DEFAULT_LENGTH);
+  strncpy(param.xPrint,xPrint,PRINT_DEFAULT_LENGTH-1);
+  param.xPrint[PRINT_DEFAULT_LENGTH-1] = '\0';
 }
 
 void SDPA::setParameterPrintXMat(char* XPrint)
 {
-  strncpy(param.XPrint,XPrint,PRINT_DEFAULT_LENGTH);
+  strncpy(param.XPrint,XPrint,PRINT_DEFAULT_LENGTH-1);
+  param.XPrint[PRINT_DEFAULT_LENGTH-1] = '\0';
 }
 
 void SDPA::setParameterPrintYMat(char* YPrint)
 {
-  strncpy(param.YPrint,YPrint,PRINT_DEFAULT_LENGTH);
+  strncpy(param.YPrint,YPrint,PRINT_DEFAULT_LENGTH-1);
+  param.YPrint[PRINT_DEFAULT_LENGTH-1] = '\0';
 }
 
 void SDPA::setParameterPrintInformation(char* infPrint)
 {
-  strncpy(param.infPrint,infPrint,PRINT_DEFAULT_LENGTH);
+  strncpy(param.infPrint,infPrint,PRINT_DEFAULT_LENGTH-1);
+  param.infPrint[PRINT_DEFAULT_LENGTH-1] = '\0';
 }
 
 void SDPA::setDisplay(FILE* Display)
