@@ -31,7 +31,9 @@ void IO::read(FILE* fpData, FILE* fpout, int& m, char* str)
 {
   while (true) {
     volatile int dummy=0; dummy++;//for gcc-3.3 bug
-    fgets(str,lengthOfString,fpData);
+    char* return_null;
+    (void) return_null;
+    return_null = fgets(str,lengthOfString,fpData);
     if (str[0]=='*' || str[0]=='"') {
       fprintf(fpout,"%s",str);
     } else {
@@ -43,13 +45,17 @@ void IO::read(FILE* fpData, FILE* fpout, int& m, char* str)
 
 void IO::read(FILE* fpData, int & nBlock)
 {
-  fscanf(fpData,"%d",&nBlock);
+  int return_null;
+  (void) return_null;
+  return_null = fscanf(fpData,"%d",&nBlock);
 }
 
 void IO::read(FILE* fpData, BlockStruct& bs)
 {
+  int return_null;
+  (void) return_null;
   for (int l=0; l<bs.nBlock; ++l) {
-    fscanf(fpData,"%*[^0-9+-]%d",&bs.blockStruct[l]);
+    return_null = fscanf(fpData,"%*[^0-9+-]%d",&bs.blockStruct[l]);
   }
   // only for SDP and LP
   for (int l=0; l<bs.nBlock; ++l) {
@@ -64,8 +70,10 @@ void IO::read(FILE* fpData, BlockStruct& bs)
 
 void IO::read(FILE* fpData, Vector& b)
 {
+  int return_null;
+  (void) return_null;
   for (int k=0; k<b.nDim; ++k) {
-    fscanf(fpData,"%*[^0-9+-]%lf",&b.ele[k]);
+    return_null = fscanf(fpData,"%*[^0-9+-]%lf",&b.ele[k]);
   }
 }
 
@@ -76,6 +84,8 @@ void IO::read(FILE* fpData, DenseLinearSpace& xMat,
   // yVec is opposite sign
   int k=0;
   double tmp;
+  int return_null;
+  (void) return_null;
   if (fscanf(fpData,"%lf",&tmp) > 0) {
     // if y[0] locates the first charcter in fpData
     // then we need the following line
@@ -84,7 +94,7 @@ void IO::read(FILE* fpData, DenseLinearSpace& xMat,
     k++;
   }
   for (; k<yVec.nDim; ++k) {
-    fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
+    return_null = fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
     yVec.ele[k] = -tmp;
     // rMessage("yVec.ele[" << k << "] = " << -tmp);
   }
@@ -160,7 +170,7 @@ void IO::read(FILE* fpData, DenseLinearSpace& xMat,
 	for (int i=0; i<size; ++i) {
 	  for (int j=0; j<size; ++j) {
 	    double tmp;
-	    fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
+	    return_null = fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
 	    if (i<=j && tmp!=0.0) {
 	      zMat.setElement_SDP(l2,i,j,tmp);
 	    }
@@ -175,7 +185,7 @@ void IO::read(FILE* fpData, DenseLinearSpace& xMat,
 	int index = bs.blockNumber[l];
 	for (int j=0; j<size; ++j) {
 	  double tmp;
-	  fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
+	  return_null = fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
 	  if (tmp!=0.0) {
 	    zMat.setElement_LP(index,tmp);
 	  }
@@ -191,7 +201,7 @@ void IO::read(FILE* fpData, DenseLinearSpace& xMat,
 	for (int i=0; i<size; ++i) {
 	  for (int j=0; j<size; ++j) {
 	    double tmp;
-	    fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
+	    return_null = fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
 	    if (i<=j && tmp!=0.0) {
 	      xMat.setElement_SDP(l2,i,j,tmp);
 	    }
@@ -206,7 +216,7 @@ void IO::read(FILE* fpData, DenseLinearSpace& xMat,
 	int index = bs.blockNumber[l];
 	for (int j=0; j<size; ++j) {
 	  double tmp;
-	  fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
+	  return_null = fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
 	  if (tmp!=0.0) {
 	    xMat.setElement_LP(index,tmp);
 	  }
@@ -275,6 +285,9 @@ void IO::setBlockStruct(FILE* fpData, InputData& inputData, int m,
   int* LP_sp_index;
   NewArray(LP_sp_index,int,bs.LP_nBlock);
 
+  int return_null;
+  (void) return_null;
+
   if (isDataSparse) {
     int i,j,k,l;
     i=j=k=l = -1000; // dummy initialize
@@ -338,7 +351,7 @@ void IO::setBlockStruct(FILE* fpData, InputData& inputData, int m,
         for (int i=0; i<size; ++i) {
           for (int j=0; j<size; ++j) {
             double tmp;
-	    fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
+	          return_null = fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
             if (i<=j && tmp!=0.0) {
               SDP_index[0].push_back(l2);
             }
@@ -351,7 +364,7 @@ void IO::setBlockStruct(FILE* fpData, InputData& inputData, int m,
 	int size  = bs.blockStruct[l];
         for (int j=0; j<size; ++j) {
           double tmp;
-	  fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
+	        return_null = fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
           if (tmp!=0.0) {
               LP_index[0].push_back(start+j);
           }
@@ -370,7 +383,7 @@ void IO::setBlockStruct(FILE* fpData, InputData& inputData, int m,
           for (int i=0; i<size; ++i) {
             for (int j=0; j<size; ++j) {
               double tmp;
-	      fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
+	      return_null = fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
               if (i<=j && tmp!=0.0) {
                 SDP_index[k+1].push_back(l2);
               }
@@ -383,7 +396,7 @@ void IO::setBlockStruct(FILE* fpData, InputData& inputData, int m,
 	  int size  = bs.blockStruct[l];
           for (int j=0; j<size; ++j) {
             double tmp;
-	    fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
+	    return_null = fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
             if (tmp!=0.0) {
               LP_index[k+1].push_back(start+j);
             }
@@ -482,6 +495,9 @@ void IO::setElement(FILE* fpData, InputData& inputData, int m,
 		    BlockStruct& bs,
                     long position, bool isDataSparse)
 {
+  int return_null;
+  (void) return_null;
+  
   // in Sparse, read C,A[k]
 
   // seed the positon of C in the fpData
@@ -552,7 +568,7 @@ void IO::setElement(FILE* fpData, InputData& inputData, int m,
 	for (int i=0; i<size; ++i) {
 	  for (int j=0; j<size; ++j) {
 	    double tmp;
-	    fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
+	    return_null = fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
 	    if (i<=j && tmp!=0.0) {
 	      inputData.C.setElement_SDP(l2,i,j,-tmp);
 	    }
@@ -565,7 +581,7 @@ void IO::setElement(FILE* fpData, InputData& inputData, int m,
 	int size  = bs.blockStruct[l];
 	for (int j=0; j<size; ++j) {
 	  double tmp;
-	  fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
+	  return_null = fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
 	  if (tmp!=0.0) {
 	    inputData.C.setElement_LP(start+j,-tmp);
 	  }
@@ -585,7 +601,7 @@ void IO::setElement(FILE* fpData, InputData& inputData, int m,
 	  for (int i=0; i<size; ++i) {
 	    for (int j=0; j<size; ++j) {
 	      double tmp;
-	      fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
+	      return_null = fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
 	      if (i<=j && tmp!=0.0) {
 		inputData.A[k].setElement_SDP(l2,i,j,tmp);
 	      }
@@ -598,7 +614,7 @@ void IO::setElement(FILE* fpData, InputData& inputData, int m,
 	  int size  = bs.blockStruct[l];
 	  for (int j=0; j<size; ++j) {
 	    double tmp;
-	    fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
+	    return_null = fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
 	    if (tmp!=0.0) {
 	      inputData.A[k].setElement_LP(start+j,tmp);
 	    }
