@@ -230,20 +230,22 @@ char Parameter::infPRINT_DEFAULT[PRINT_DEFAULT_LENGTH] = "%+10.16e";
 
 void Parameter::readFile(FILE* parameterFile)
 {
-  fscanf(parameterFile,"%d%*[^\n]",&maxIteration);
-  fscanf(parameterFile,"%lf%*[^\n]",&epsilonStar);
-  fscanf(parameterFile,"%lf%*[^\n]",&lambdaStar);
-  fscanf(parameterFile,"%lf%*[^\n]",&omegaStar);
-  fscanf(parameterFile,"%lf%*[^\n]",&lowerBound);
-  fscanf(parameterFile,"%lf%*[^\n]",&upperBound);
-  fscanf(parameterFile,"%lf%*[^\n]",&betaStar);
-  fscanf(parameterFile,"%lf%*[^\n]",&betaBar);
-  fscanf(parameterFile,"%lf%*[^\n]",&gammaStar);
-  fscanf(parameterFile,"%lf%*[^\n]",&epsilonDash);
-  fscanf(parameterFile,"%s %*[^\n]",xPrint);
-  fscanf(parameterFile,"%s %*[^\n]",XPrint);
-  fscanf(parameterFile,"%s %*[^\n]",YPrint);
-  fscanf(parameterFile,"%s %*[^\n]",infPrint);
+  int return_null;
+  (void) return_null; 
+  return_null = fscanf(parameterFile,"%d%*[^\n]",&maxIteration);
+  return_null = fscanf(parameterFile,"%lf%*[^\n]",&epsilonStar);
+  return_null = fscanf(parameterFile,"%lf%*[^\n]",&lambdaStar);
+  return_null = fscanf(parameterFile,"%lf%*[^\n]",&omegaStar);
+  return_null = fscanf(parameterFile,"%lf%*[^\n]",&lowerBound);
+  return_null = fscanf(parameterFile,"%lf%*[^\n]",&upperBound);
+  return_null = fscanf(parameterFile,"%lf%*[^\n]",&betaStar);
+  return_null = fscanf(parameterFile,"%lf%*[^\n]",&betaBar);
+  return_null = fscanf(parameterFile,"%lf%*[^\n]",&gammaStar);
+  return_null = fscanf(parameterFile,"%lf%*[^\n]",&epsilonDash);
+  return_null = fscanf(parameterFile,"%s %*[^\n]",xPrint);
+  return_null = fscanf(parameterFile,"%s %*[^\n]",XPrint);
+  return_null = fscanf(parameterFile,"%s %*[^\n]",YPrint);
+  return_null = fscanf(parameterFile,"%s %*[^\n]",infPrint);
   if (strcmp(xPrint,NO_P_FORMAT)!=0 && xPrint[0]!='%') {
     rMessage("Strange xPrint[" << xPrint << "]"
 	     " migh cause trouble when printing x");
