@@ -31,6 +31,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 #include <sys/time.h>
 #include <string>
 #include <cstring>
+#include <new>
+#include <exception>
 
 
 namespace sdpa {
@@ -67,7 +69,7 @@ exit(false);}
 #define NewArray(val,type,number) \
   {val = NULL; \
     try{ val = new type[number]; } \
-    catch(bad_alloc){ \
+    catch(const std::bad_alloc& e){ \
         rMessage("Memory Exhausted (bad_alloc)"); abort(); } \
     catch(...){ \
         rMessage("Fatal Error (related memory allocation"); abort(); } \
